==> spring-batch-core-4.3.10-sources.jar: org/springframework/batch/core/job/flow/Flow.java <==
/*
 * Copyright 2006-2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.batch.core.job.flow;

import java.util.Collection;

/**
 * @author Dave Syer
 * @since 2.0
 */
public interface Flow {

	/**
	 * @return the name of the flow
	 */
	String getName();

	/**
	 * Retrieve the State with the given name. If there is no State with the
	 * given name, then return null.
	 * 
	 * @param stateName the name of the state to retrieve
	 * @return the State
	 */
	State getState(String stateName);

	/**
	 * @param executor the {@link FlowExecutor} instance to use for the flow execution.
	 * @return a {@link FlowExecution} containing the exit status of the flow.
	 *
	 * @throws FlowExecutionException thrown if error occurs during flow execution.
	 */
	FlowExecution start(FlowExecutor executor) throws FlowExecutionException;

	/**
	 * @param stateName the name of the state to resume on.
	 * @param executor the context to be passed into each state executed.
	 * @return a {@link FlowExecution} containing the exit status of the flow.
	 *
	 * @throws FlowExecutionException thrown if error occurs during flow execution.
	 */
	FlowExecution resume(String stateName, FlowExecutor executor) throws FlowExecutionException;

	/**
	 * Convenient accessor for clients needing to explore the states of this
	 * flow.
	 * @return the states
	 */
	Collection<State> getStates();

}

==> spring-batch-core-5.0.2-sources.jar: org/springframework/batch/core/job/flow/Flow.java <==
/*
 * Copyright 2006-2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.batch.core.job.flow;

import java.util.Collection;

/**
 * @author Dave Syer
 * @since 2.0
 */
public interface Flow {

	/**
	 * @return the name of the flow
	 */
	String getName();

	/**
	 * Retrieve the State with the given name. If there is no State with the given name,
	 * then return null.
	 * @param stateName the name of the state to retrieve
	 * @return the State
	 */
	State getState(String stateName);

	/**
	 * @param executor the {@link FlowExecutor} instance to use for the flow execution.
	 * @return a {@link FlowExecution} containing the exit status of the flow.
	 * @throws FlowExecutionException thrown if error occurs during flow execution.
	 */
	FlowExecution start(FlowExecutor executor) throws FlowExecutionException;

	/**
	 * @param stateName the name of the state to resume on.
	 * @param executor the context to be passed into each state executed.
	 * @return a {@link FlowExecution} containing the exit status of the flow.
	 * @throws FlowExecutionException thrown if error occurs during flow execution.
	 */
	FlowExecution resume(String stateName, FlowExecutor executor) throws FlowExecutionException;

	/**
	 * Convenient accessor for clients needing to explore the states of this flow.
	 * @return the states
	 */
	Collection<State> getStates();

}
